@@ -1,17 +1,14 @@
 package S2::FW::Controller::Firewall;
-use Mojo::Base 'Mojolicious::Controller';
+use Mojo::Base 'Mojolicious::Controller', -signatures;
 
 use Mojo::IOLoop::Subprocess;
 
-sub status {
-    my $self = shift;
+sub status ($self) {
     return $self->render(rows => $self->query_nft);
 }
 
-sub change {
-    my $self = shift;
-
-    my $ip = $self->param('ip');
+sub change ($self) {
+    my $ip       = $self->param('ip');
     my $new_mode = $self->param('mode');
     return $self->render(text => 'Bad Request', status => 400) unless $ip and $new_mode;
 
@@ -28,7 +25,7 @@ sub change {
         sub {
             my $process = shift;
             $self->log->info("NFTables: $ip → $new_mode");
-            $self->log->debug("nft " . join('; ', @cmd));
+            $self->log->debug('nft ' . join('; ', @cmd));
             exec '/usr/sbin/nft', join('; ', @cmd);
         },
         sub {
